@@ -22,6 +22,7 @@
 #include "common/chapters/chapters.h"
 #include "common/chapters/dvd.h"
 #include "common/construct.h"
+#include "common/debugging.h"
 #include "common/ebml.h"
 #include "common/error.h"
 #include "common/iso3166.h"
@@ -30,6 +31,7 @@
 #include "common/mm_file_io.h"
 #include "common/mm_proxy_io.h"
 #include "common/mm_text_io.h"
+#include "common/path.h"
 #include "common/regex.h"
 #include "common/strings/editing.h"
 #include "common/strings/formatting.h"
@@ -41,6 +43,10 @@ using namespace libmatroska;
 
 namespace mtx::chapters {
 
+namespace {
+debugging_option_c s_debug{"chapters|chapter_parser"};
+}
+
 /** The default language for all chapter entries that don't have their own. */
 mtx::bcp47::language_c g_default_language;
 /** The default country for all chapter entries that don't have their own. */
@@ -48,9 +54,9 @@ std::string g_default_country;
 
 translatable_string_c g_chapter_generation_name_template{YT("Chapter <NUM:2>")};
 
-#define SIMCHAP_RE_TIMESTAMP_LINE "^\\s*CHAPTER\\d+\\s*=\\s*(\\d+)\\s*:\\s*(\\d+)\\s*:\\s*(\\d+)\\s*[\\.,]\\s*(\\d+)"
-#define SIMCHAP_RE_TIMESTAMP      "^\\s*CHAPTER\\d+\\s*=(.*)"
-#define SIMCHAP_RE_NAME_LINE      "^\\s*CHAPTER\\d+NAME\\s*=(.*)"
+constexpr auto SIMCHAP_RE_TIMESTAMP_LINE = "^\\s*CHAPTER\\d+\\s*=\\s*(\\d+)\\s*:\\s*(\\d+)\\s*:\\s*(\\d+)\\s*[\\.,]\\s*(\\d+)";
+constexpr auto SIMCHAP_RE_TIMESTAMP      = "^\\s*CHAPTER\\d+\\s*=(.*)";
+constexpr auto SIMCHAP_RE_NAME_LINE      = "^\\s*CHAPTER\\d+NAME\\s*=(.*)";
 
 /** \brief Throw a special chapter parser exception.
 
@@ -479,26 +485,22 @@ remove_elements_unsupported_by_webm(EbmlMaster &master) {
   static std::unordered_map<uint32_t, bool> s_supported_elements, s_readd_with_defaults;
 
   if (s_supported_elements.empty()) {
-#define add(ref) s_supported_elements[ EBML_ID_VALUE(EBML_ID(ref)) ] = true;
-    add(KaxChapters);
-    add(KaxEditionEntry);
-    add(KaxChapterAtom);
-    add(KaxChapterUID);
-    add(KaxChapterStringUID);
-    add(KaxChapterTimeStart);
-    add(KaxChapterTimeEnd);
-    add(KaxChapterDisplay);
-    add(KaxChapterString);
-    add(KaxChapterLanguage);
-    add(KaxChapterCountry);
-#undef add
+    s_supported_elements[ EBML_ID_VALUE(EBML_ID(KaxChapters))            ] = true;
+    s_supported_elements[ EBML_ID_VALUE(EBML_ID(KaxEditionEntry))        ] = true;
+    s_supported_elements[ EBML_ID_VALUE(EBML_ID(KaxChapterAtom))         ] = true;
+    s_supported_elements[ EBML_ID_VALUE(EBML_ID(KaxChapterUID))          ] = true;
+    s_supported_elements[ EBML_ID_VALUE(EBML_ID(KaxChapterStringUID))    ] = true;
+    s_supported_elements[ EBML_ID_VALUE(EBML_ID(KaxChapterTimeStart))    ] = true;
+    s_supported_elements[ EBML_ID_VALUE(EBML_ID(KaxChapterTimeEnd))      ] = true;
+    s_supported_elements[ EBML_ID_VALUE(EBML_ID(KaxChapterDisplay))      ] = true;
+    s_supported_elements[ EBML_ID_VALUE(EBML_ID(KaxChapterString))       ] = true;
+    s_supported_elements[ EBML_ID_VALUE(EBML_ID(KaxChapterLanguage))     ] = true;
+    s_supported_elements[ EBML_ID_VALUE(EBML_ID(KaxChapterCountry))      ] = true;
 
-#define add(ref) s_readd_with_defaults[ EBML_ID_VALUE(EBML_ID(ref)) ] = true;
-    add(KaxEditionFlagDefault);
-    add(KaxEditionFlagHidden);
-    add(KaxChapterFlagEnabled);
-    add(KaxChapterFlagHidden);
-#undef add
+    s_readd_with_defaults[ EBML_ID_VALUE(EBML_ID(KaxEditionFlagDefault)) ] = true;
+    s_readd_with_defaults[ EBML_ID_VALUE(EBML_ID(KaxEditionFlagHidden))  ] = true;
+    s_readd_with_defaults[ EBML_ID_VALUE(EBML_ID(KaxChapterFlagEnabled)) ] = true;
+    s_readd_with_defaults[ EBML_ID_VALUE(EBML_ID(KaxChapterFlagHidden))  ] = true;
   }
 
   auto idx = 0u;
@@ -622,9 +624,7 @@ remove_entries(int64_t min_ts,
     if (entries[i].remove && (entries[i].start < min_ts) && (entries[i].end > min_ts))
       entries[i].spans = true;
 
-    mxverb(3,
-           fmt::format("remove_chapters: entries[{0}]: remove {1} spans {2} start {3} end {4}\n",
-                       i, entries[i].remove, entries[i].spans, entries[i].start, entries[i].end));
+    mxdebug_if(s_debug, fmt::format("remove_chapters: entries[{0}]: remove {1} spans {2} start {3} end {4}\n", i, entries[i].remove, entries[i].spans, entries[i].start, entries[i].end));
 
     // Spanning entries must be kept, and their start timestamp must be
     // adjusted. Entries that are to be deleted will be deleted later and
@@ -696,7 +696,7 @@ merge_entries(EbmlMaster &master) {
     int64_t start_ts = get_start(*atom, 0);
     int64_t end_ts   = get_end(*atom);
 
-    mxverb(3, fmt::format("chapters: merge_entries: looking for {0} with {1}, {2}\n", uid, start_ts, end_ts));
+    mxdebug_if(s_debug, fmt::format("chapters: merge_entries: looking for {0} with {1}, {2}\n", uid, start_ts, end_ts));
 
     // Now iterate over all remaining atoms and find those with the same
     // UID.
@@ -745,7 +745,7 @@ merge_entries(EbmlMaster &master) {
           ++merge_child_idx;
       }
 
-      mxverb(3, fmt::format("chapters: merge_entries:   found one at {0} with {1}, {2}; merged to {3}, {4}\n", merge_idx, merge_start_ts, merge_end_ts, start_ts, end_ts));
+      mxdebug_if(s_debug, fmt::format("chapters: merge_entries:   found one at {0} with {1}, {2}; merged to {3}, {4}\n", merge_idx, merge_start_ts, merge_end_ts, start_ts, end_ts));
 
       // Finally remove the entry itself.
       delete master[merge_idx];
@@ -1122,7 +1122,7 @@ format_name_template(std::string const &name_template,
   auto timestamp_re         = mtx::regex::jp::Regex{"<START(?::([^>]+))?>"};
   auto file_name_re         = mtx::regex::jp::Regex{"<FILE_NAME>"};
   auto file_name_ext_re     = mtx::regex::jp::Regex{"<FILE_NAME_WITH_EXT>"};
-  auto appended_file_name_p = bfs::path{appended_file_name};
+  auto appended_file_name_p = mtx::fs::to_path(appended_file_name);
 
   name = mtx::regex::replace(name, number_re, "g", [=](auto const &match) {
     auto number_str    = fmt::format("{0}", chapter_number);
@@ -1142,8 +1142,8 @@ format_name_template(std::string const &name_template,
     return mtx::string::format_timestamp(start_timestamp.to_ns(), format);
   });
 
-  name = mtx::regex::replace(name, file_name_re,     "g", appended_file_name_p.stem().string());
-  name = mtx::regex::replace(name, file_name_ext_re, "g", appended_file_name_p.filename().string());
+  name = mtx::regex::replace(name, file_name_re,     "g", appended_file_name_p.stem().u8string());
+  name = mtx::regex::replace(name, file_name_ext_re, "g", appended_file_name_p.filename().u8string());
 
   return name;
 }
@@ -1194,8 +1194,9 @@ create_editions_and_chapters(std::vector<std::vector<timestamp_c>> const &editio
                                                                     new libmatroska::KaxChapterTimeStart, timestamp.to_ns());
 
       if (!name.empty())
-        atom->PushElement(*mtx::construct::cons<libmatroska::KaxChapterDisplay>(new libmatroska::KaxChapterString,   name,
-                                                                                new libmatroska::KaxChapterLanguage, use_language.get_iso639_2_alpha_3_code_or("und")));
+        atom->PushElement(*mtx::construct::cons<libmatroska::KaxChapterDisplay>(new libmatroska::KaxChapterString,    name,
+                                                                                new libmatroska::KaxChapterLanguage,  use_language.get_iso639_2_alpha_3_code_or("und"),
+                                                                                new libmatroska::KaxChapLanguageIETF, use_language.format()));
 
       edition->PushElement(*atom);
     }
@@ -1212,7 +1213,7 @@ set_languages_in_display(libmatroska::KaxChapterDisplay &display,
 
   GetChild<libmatroska::KaxChapLanguageIETF>(display).SetValue(parsed_language.format());
 
-  if (parsed_language.has_valid_iso639_code())
+  if (parsed_language.has_valid_iso639_2_code())
     GetChild<libmatroska::KaxChapterLanguage>(display).SetValue(parsed_language.get_iso639_alpha_3_code());
 }
 
