@@ -41,13 +41,13 @@ mm_multi_file_io_c::~mm_multi_file_io_c() {
   close_multi_file_io();
 }
 
-uint64
+uint64_t
 mm_multi_file_io_c::getFilePointer() {
   return p_func()->current_pos;
 }
 
 void
-mm_multi_file_io_c::setFilePointer(int64 offset,
+mm_multi_file_io_c::setFilePointer(int64_t offset,
                                    libebml::seek_mode mode) {
   auto p = p_func();
 
@@ -73,7 +73,7 @@ mm_multi_file_io_c::setFilePointer(int64 offset,
   }
 }
 
-uint32
+uint32_t
 mm_multi_file_io_c::_read(void *buffer,
                           size_t size) {
   auto p                = p_func();
