@@ -287,7 +287,8 @@ set_simple(KaxTag &tag,
   if (language.has_valid_iso639_2_code())
     GetChild<KaxTagLangue>(k_simple_tag).SetValue(language.get_iso639_alpha_3_code());
 
-  GetChild<KaxTagLanguageIETF>(k_simple_tag).SetValue(language.format());
+  if (!mtx::bcp47::language_c::is_disabled())
+    GetChild<KaxTagLanguageIETF>(k_simple_tag).SetValue(language.format());
 }
 
 void
@@ -302,7 +303,7 @@ set_target_type(KaxTag &tag,
 
 void
 remove_elements_unsupported_by_webm(EbmlMaster &master) {
-  static auto s_supported_elements = std::map<uint32, bool>{};
+  static auto s_supported_elements = std::map<uint32_t, bool>{};
 
   if (s_supported_elements.empty()) {
     s_supported_elements[ EBML_ID_VALUE(EBML_ID(KaxTags))               ] = true;
