@@ -4,7 +4,7 @@
 
    Distributed under the GPL v2
    see the file COPYING for details
-   or visit http://www.gnu.org/copyleft/gpl.html
+   or visit https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 
    RealMedia demultiplexer module
 
@@ -17,6 +17,7 @@
 
 #include "common/bit_reader.h"
 #include "common/codec.h"
+#include "common/debugging.h"
 #include "common/ebml.h"
 #include "common/endian.h"
 #include "common/error.h"
@@ -33,6 +34,10 @@
 
 using namespace libmatroska;
 
+namespace {
+debugging_option_c s_debug{"real_reader"};
+}
+
 /*
    Description of the RealMedia file format:
    http://www.pcisys.net/~melanson/codecs/rmff.htm
@@ -221,7 +226,7 @@ real_reader_c::parse_headers() {
         ok = false;
       }
 
-      mxverb(2, fmt::format("real_reader: extra_data_size: {0}\n", dmx->extra_data->get_size()));
+      mxdebug_if(s_debug, fmt::format("real_reader: extra_data_size: {0}\n", dmx->extra_data->get_size()));
 
       if (ok) {
         dmx->private_data = memory_c::clone(ts_data, ts_size);
@@ -240,13 +245,13 @@ real_reader_c::create_video_packetizer(real_demuxer_cptr dmx) {
   if (strcmp(dmx->fourcc, "RV40"))
     dmx->rv_dimensions = true;
 
-  show_packetizer_info(dmx->track->id, PTZR(dmx->ptzr));
+  show_packetizer_info(dmx->track->id, ptzr(dmx->ptzr));
 }
 
 void
 real_reader_c::create_dnet_audio_packetizer(real_demuxer_cptr dmx) {
   dmx->ptzr = add_packetizer(new ac3_bs_packetizer_c(this, m_ti, dmx->samples_per_second, dmx->channels, dmx->bsid));
-  show_packetizer_info(dmx->track->id, PTZR(dmx->ptzr));
+  show_packetizer_info(dmx->track->id, ptzr(dmx->ptzr));
 }
 
 void
@@ -259,7 +264,7 @@ real_reader_c::create_aac_audio_packetizer(real_demuxer_cptr dmx) {
   if ((dmx->extra_data) && (4 < dmx->extra_data->get_size())) {
     const unsigned char *extra_data = dmx->extra_data->get_buffer();
     uint32_t extra_len              = get_uint32_be(extra_data);
-    mxverb(2, fmt::format("real_reader: extra_len: {0}\n", extra_len));
+    mxdebug_if(s_debug, fmt::format("real_reader: extra_len: {0}\n", extra_len));
 
     if ((4 + extra_len) <= dmx->extra_data->get_size()) {
       auto parsed_audio_config = mtx::aac::parse_audio_specific_config(&extra_data[4 + 1], extra_len - 1);
@@ -268,12 +273,10 @@ real_reader_c::create_aac_audio_packetizer(real_demuxer_cptr dmx) {
 
       audio_config = *parsed_audio_config;
 
-      mxverb(2,
-             fmt::format("real_reader: 1. profile: {0}, channels: {1}, sample_rate: {2}, output_sample_rate: {3}, sbr: {4}\n",
-                         audio_config.profile, audio_config.channels, audio_config.sample_rate, audio_config.output_sample_rate, audio_config.sbr));
+      mxdebug_if(s_debug, fmt::format("real_reader: 1. profile: {0}, channels: {1}, sample_rate: {2}, output_sample_rate: {3}, sbr: {4}\n", audio_config.profile, audio_config.channels, audio_config.sample_rate, audio_config.output_sample_rate, audio_config.sbr));
 
       if (audio_config.sbr)
-        audio_config.profile = AAC_PROFILE_SBR;
+        audio_config.profile = mtx::aac::PROFILE_SBR;
 
       profile_detected = true;
     }
@@ -294,11 +297,11 @@ real_reader_c::create_aac_audio_packetizer(real_demuxer_cptr dmx) {
 
   auto detected_profile = audio_config.profile;
   if (audio_config.sbr)
-    audio_config.profile = AAC_PROFILE_SBR;
+    audio_config.profile = mtx::aac::PROFILE_SBR;
 
   if (   (mtx::includes(m_ti.m_all_aac_is_sbr, tid) && m_ti.m_all_aac_is_sbr[tid])
       || (mtx::includes(m_ti.m_all_aac_is_sbr, -1)  && m_ti.m_all_aac_is_sbr[-1]))
-    audio_config.profile = AAC_PROFILE_SBR;
+    audio_config.profile = mtx::aac::PROFILE_SBR;
 
   if (profile_detected
       &&
@@ -306,17 +309,15 @@ real_reader_c::create_aac_audio_packetizer(real_demuxer_cptr dmx) {
        || (mtx::includes(m_ti.m_all_aac_is_sbr, -1)  && !m_ti.m_all_aac_is_sbr[-1])))
     audio_config.profile = detected_profile;
 
-  mxverb(2,
-         fmt::format("real_reader: 2. profile: {0}, channels: {1}, sample_rate: {2}, output_sample_rate: {3}, sbr: {4}\n",
-                     audio_config.profile, audio_config.channels, audio_config.sample_rate, audio_config.output_sample_rate, audio_config.sbr));
+  mxdebug_if(s_debug, fmt::format("real_reader: 2. profile: {0}, channels: {1}, sample_rate: {2}, output_sample_rate: {3}, sbr: {4}\n", audio_config.profile, audio_config.channels, audio_config.sample_rate, audio_config.output_sample_rate, audio_config.sbr));
 
   dmx->is_aac = true;
   dmx->ptzr   = add_packetizer(new aac_packetizer_c(this, m_ti, audio_config, aac_packetizer_c::headerless));
 
-  show_packetizer_info(tid, PTZR(dmx->ptzr));
+  show_packetizer_info(tid, ptzr(dmx->ptzr));
 
-  if (AAC_PROFILE_SBR == audio_config.profile)
-    PTZR(dmx->ptzr)->set_audio_output_sampling_freq(audio_config.output_sample_rate);
+  if (mtx::aac::PROFILE_SBR == audio_config.profile)
+    ptzr(dmx->ptzr).set_audio_output_sampling_freq(audio_config.output_sample_rate);
 
   // AAC packetizers might need the timestamp of the first packet in order
   // to fill in stuff. Let's misuse ref_timestamp for that.
@@ -338,7 +339,7 @@ real_reader_c::create_audio_packetizer(real_demuxer_cptr dmx) {
     m_ti.m_private_data = dmx->private_data;
     dmx->ptzr           = add_packetizer(new ra_packetizer_c(this, m_ti, dmx->samples_per_second, dmx->channels, dmx->bits_per_sample, get_uint32_be(dmx->fourcc)));
 
-    show_packetizer_info(dmx->track->id, PTZR(dmx->ptzr));
+    show_packetizer_info(dmx->track->id, ptzr(dmx->ptzr));
   }
 }
 
@@ -443,7 +444,7 @@ real_reader_c::read(generic_packetizer_c *,
     // packetizer adjust its data accordingly.
     if (dmx->first_frame) {
       dmx->ref_timestamp = timestamp;
-      PTZR(dmx->ptzr)->set_displacement_maybe(timestamp);
+      ptzr(dmx->ptzr).set_displacement_maybe(timestamp);
     }
 
     deliver_aac_frames(dmx, *mem);
@@ -471,7 +472,7 @@ real_reader_c::queue_one_audio_frame(real_demuxer_cptr dmx,
 
   dmx->last_timestamp = timestamp;
 
-  mxverb_tid(2, m_ti.m_fname, dmx->track->id, fmt::format("enqueueing one length {0} timestamp {1} flags 0x{2:08x}\n", mem->get_size(), timestamp, flags));
+  mxdebug_if(s_debug, fmt::format("'{0}' track {1}: enqueueing one length {2} timestamp {3} flags 0x{4:08x}\n", m_ti.m_fname, dmx->track->id, mem->get_size(), timestamp, flags));
 }
 
 void
@@ -503,11 +504,9 @@ real_reader_c::deliver_audio_frames(real_demuxer_cptr dmx,
 
   for (i = 0; i < dmx->segments.size(); i++) {
     rv_segment_cptr segment = dmx->segments[i];
-    mxverb_tid(2, m_ti.m_fname, dmx->track->id,
-               fmt::format("delivering audio length {0} timestamp {1} flags 0x{2:08x} duration {3}\n",
-                           segment->data->get_size(), dmx->last_timestamp, segment->flags, duration));
+    mxdebug_if(s_debug, fmt::format("'{0}' track {1}: delivering audio length {2} timestamp {3} flags 0x{4:08x} duration {5}\n", m_ti.m_fname, dmx->track->id, segment->data->get_size(), dmx->last_timestamp, segment->flags, duration));
 
-    PTZR(dmx->ptzr)->process(new packet_t(segment->data, dmx->last_timestamp, duration,
+    ptzr(dmx->ptzr).process(new packet_t(segment->data, dmx->last_timestamp, duration,
                                           (segment->flags & RMFF_FRAME_FLAG_KEYFRAME) == RMFF_FRAME_FLAG_KEYFRAME ? -1 : dmx->ref_timestamp));
     if ((segment->flags & 2) == 2)
       dmx->ref_timestamp = dmx->last_timestamp;
@@ -528,7 +527,7 @@ real_reader_c::deliver_aac_frames(real_demuxer_cptr dmx,
   }
 
   int num_sub_packets = chunk[1] >> 4;
-  mxverb(2, fmt::format("real_reader: num_sub_packets = {0}\n", num_sub_packets));
+  mxdebug_if(s_debug, fmt::format("real_reader: num_sub_packets = {0}\n", num_sub_packets));
   if ((2 + num_sub_packets * 2) > length) {
     mxwarn_tid(m_ti.m_fname, dmx->track->id, fmt::format(Y("Short AAC audio packet (length: {0} < {1})\n"), length, 2 + num_sub_packets * 2));
     return;
@@ -539,7 +538,7 @@ real_reader_c::deliver_aac_frames(real_demuxer_cptr dmx,
     int sub_length  = get_uint16_be(&chunk[2 + i * 2]);
     len_check      += sub_length;
 
-    mxverb(2, fmt::format("real_reader: {0}: length {1}\n", i, sub_length));
+    mxdebug_if(s_debug, fmt::format("real_reader: {0}: length {1}\n", i, sub_length));
   }
 
   if (len_check != length) {
@@ -550,7 +549,7 @@ real_reader_c::deliver_aac_frames(real_demuxer_cptr dmx,
   int data_idx = 2 + num_sub_packets * 2;
   for (i = 0; i < num_sub_packets; i++) {
     int sub_length = get_uint16_be(&chunk[2 + i * 2]);
-    PTZR(dmx->ptzr)->process(new packet_t(memory_c::borrow(&chunk[data_idx], sub_length)));
+    ptzr(dmx->ptzr).process(new packet_t(memory_c::borrow(&chunk[data_idx], sub_length)));
     data_idx += sub_length;
   }
 }
@@ -599,7 +598,7 @@ real_reader_c::assemble_video_packet(real_demuxer_cptr dmx,
                                              0,
                                              (assembled->flags & RMFF_FRAME_FLAG_KEYFRAME) == RMFF_FRAME_FLAG_KEYFRAME ? VFT_IFRAME : VFT_PFRAMEAUTOMATIC,
                                              VFT_NOBFRAME);
-    PTZR(dmx->ptzr)->process(packet);
+    ptzr(dmx->ptzr).process(packet);
 
     assembled->allocated_by_rmff = 0;
     rmff_release_frame(assembled);
@@ -704,7 +703,7 @@ real_reader_c::set_dimensions(real_demuxer_cptr dmx,
 
     }
 
-    auto video = GetChild<KaxTrackVideo>(*PTZR(dmx->ptzr)->get_track_entry());
+    auto video = GetChild<KaxTrackVideo>(*ptzr(dmx->ptzr).get_track_entry());
     GetChild<KaxVideoPixelWidth>(video).SetValue(width);
     GetChild<KaxVideoPixelHeight>(video).SetValue(height);
 
