@@ -88,12 +88,12 @@ TrackItem::operator <(QTreeWidgetItem const &cmp)
   auto otherTrack = static_cast<TrackItem const &>(cmp).m_track;
   auto column     = treeWidget()->sortColumn();
 
-  return 1 == column                                     ? m_track->nameForType() <  otherTrack->nameForType()
-       : 2 == column                                     ? m_track->m_codec       <  otherTrack->m_codec
-       : 3 == column                                     ? m_track->m_language    <  otherTrack->m_language
-       : (m_track->m_id >= 0) && (otherTrack->m_id >= 0) ? m_track->m_id          <  otherTrack->m_id
-       : (m_track->m_id <  0) && (otherTrack->m_id <  0) ? m_track->m_codec       <  otherTrack->m_codec
-       :                                                   m_track->m_id          >= 0;
+  return 1 == column                                     ? m_track->nameForType()          <  otherTrack->nameForType()
+       : 2 == column                                     ? m_track->m_codec                <  otherTrack->m_codec
+       : 3 == column                                     ? Q(m_track->m_language.format()) <  Q(otherTrack->m_language.format())
+       : (m_track->m_id >= 0) && (otherTrack->m_id >= 0) ? m_track->m_id                   <  otherTrack->m_id
+       : (m_track->m_id <  0) && (otherTrack->m_id <  0) ? m_track->m_codec                <  otherTrack->m_codec
+       :                                                   m_track->m_id                   >= 0;
 }
 
 TrackItem *
@@ -102,7 +102,7 @@ TrackItem::create(Track const &track) {
       track.m_id >= 0 ? QString::number(track.m_id) : QString{},
       track.nameForType(),
       track.m_codec,
-      track.m_language,
+      Q(track.m_language.format()),
     }};
 
   item->setTextAlignment(0, Qt::AlignRight | Qt::AlignVCenter);
@@ -204,13 +204,13 @@ DiscLibraryItem::create(std::string const &language,
       biggestThumbnail = currentThumbnail;
   }
 
-  auto languageIdx  = mtx::iso639::look_up(language);
-  auto languageName = languageIdx ? Q(mtx::iso639::g_languages[*languageIdx].english_name) : Q(language);
+  auto languageOpt  = mtx::iso639::look_up(language);
+  auto languageName = languageOpt ? Q(languageOpt->english_name) : Q(language);
 
   auto item = new DiscLibraryItem{info, QStringList{
     languageName,
     Q(info.m_title),
-    biggestThumbnail == end ? Q("") : Q(biggestThumbnail->m_file_name.filename().string()),
+    biggestThumbnail == end ? Q("") : Q(biggestThumbnail->m_file_name.filename().u8string()),
     biggestThumbnail == end ? Q("") : Q("%1x%2").arg(biggestThumbnail->m_width).arg(biggestThumbnail->m_height),
   }};
 
@@ -228,7 +228,7 @@ DiscLibraryItem::create(std::string const &language,
 // ------------------------------------------------------------
 
 SelectPlaylistDialog::SelectPlaylistDialog(QWidget *parent,
-                                           QList<SourceFilePtr> const &scannedFiles,
+                                           QVector<SourceFilePtr> const &scannedFiles,
                                            std::optional<mtx::bluray::disc_library::disc_library_t> const &discLibrary)
   : QDialog{parent, Qt::Dialog | Qt::WindowMaximizeButtonHint | Qt::WindowCloseButtonHint}
   , ui{new Ui::SelectPlaylistDialog}
@@ -358,34 +358,41 @@ SelectPlaylistDialog::onScannedFileSelected(QTreeWidgetItem *current,
   Util::resizeViewColumnsToContents(ui->playlistItems);
 }
 
-SourceFilePtr
+QVector<SourceFilePtr>
 SelectPlaylistDialog::select() {
   if (exec() == QDialog::Rejected)
     return {};
 
-  auto modelIdx = Util::selectedRowIdx(ui->scannedFiles);
-  if (!modelIdx.isValid())
+  QVector<SourceFilePtr> selectedSourceFiles;
+  Util::withSelectedIndexes(ui->scannedFiles, [this, &selectedSourceFiles](QModelIndex const &sourceFileIdx) {
+      if (!sourceFileIdx.isValid())
+        return;
+
+      auto fileItem = dynamic_cast<ScannedFileItem *>(ui->scannedFiles->invisibleRootItem()->child(sourceFileIdx.row()));
+      if (!fileItem)
+        return;
+
+      auto idx = Util::findPtr(fileItem->m_file, m_scannedFiles);
+      if (idx < 0)
+        return;
+
+      selectedSourceFiles << m_scannedFiles[idx];
+    });
+
+  if (selectedSourceFiles.isEmpty())
     return {};
 
-  auto fileItem = dynamic_cast<ScannedFileItem *>(ui->scannedFiles->invisibleRootItem()->child(modelIdx.row()));
-  if (!fileItem)
-    return {};
+  auto discLibraryIdx = Util::selectedRowIdx(ui->discLibrary);
 
-  auto idx = Util::findPtr(fileItem->m_file, m_scannedFiles);
-  if (idx < 0)
-    return {};
+  if (!discLibraryIdx.isValid())
+    return selectedSourceFiles;
 
-  auto sourceFile = m_scannedFiles[idx];
-  modelIdx        = Util::selectedRowIdx(ui->discLibrary);
-
-  if (!modelIdx.isValid())
-    return sourceFile;
-
-  auto libraryItem = dynamic_cast<DiscLibraryItem *>(ui->discLibrary->invisibleRootItem()->child(modelIdx.row()));
+  auto libraryItem = dynamic_cast<DiscLibraryItem *>(ui->discLibrary->invisibleRootItem()->child(discLibraryIdx.row()));
   if (libraryItem)
-    sourceFile->m_discLibraryInfoToAdd = libraryItem->m_info;
+    for (auto &sourceFile : selectedSourceFiles)
+      sourceFile->m_discLibraryInfoToAdd = libraryItem->m_info;
 
-  return sourceFile;
+  return selectedSourceFiles;
 }
 
 }
