@@ -35,7 +35,7 @@ public:
   bool m_removeDialogNormalizationGain{};
   mtx::bcp47::language_c m_language;
   QString m_name, m_codec, m_tags, m_delay, m_stretchBy, m_defaultDuration, m_timestamps, m_aspectRatio, m_displayWidth, m_displayHeight, m_cropping, m_characterSet, m_additionalOptions;
-  unsigned int m_defaultTrackFlag{}, m_forcedTrackFlag{}, m_stereoscopy{}, m_naluSizeLength{}, m_cues{}, m_aacIsSBR{};
+  unsigned int m_defaultTrackFlag{}, m_forcedTrackFlag{}, m_stereoscopy{}, m_cues{}, m_aacIsSBR{};
   TrackCompression m_compression{TrackCompression::Default};
   std::optional<bool> m_effectiveDefaultTrackFlag;
 
