@@ -59,23 +59,32 @@ gatherGeneralInfo(QStringList &info) {
 
 void
 gatherOperatingSystemInfo(QStringList &info) {
-  info << Q("") << Q("## Operating system");
-
+  QString osName, osVersion;
   auto versionInfo = QOperatingSystemVersion::current();
-  auto versionNum  = QStringList{};
 
-  if (versionInfo.majorVersion() != -1)
-    versionNum << QString::number(versionInfo.majorVersion());
-  if (versionInfo.minorVersion() != -1)
-    versionNum << QString::number(versionInfo.minorVersion());
-  if (versionInfo.microVersion() != -1)
-    versionNum << QString::number(versionInfo.microVersion());
+  if (versionInfo.type() != QOperatingSystemVersion::Unknown) {
+    osName = versionInfo.name();
+  } else {
+    osName = QSysInfo::productType();
+  }
 
-  auto osName    = versionInfo.name();
-  auto osVersion = versionNum.join(Q("."));
+  if (versionInfo.majorVersion() != -1) {
+    osVersion += QString::number(versionInfo.majorVersion());
+    if (versionInfo.minorVersion() != -1) {
+      osVersion += QLatin1Char('.');
+      osVersion += QString::number(versionInfo.minorVersion());
+      if (versionInfo.microVersion() != -1) {
+        osVersion += QLatin1Char('.');
+        osVersion += QString::number(versionInfo.microVersion());
+      }
+    }
+  } else {
+    osVersion = QSysInfo::productVersion();
+  }
 
+  info << Q("") << Q("## Operating system");
   info << Q("* Name: %1").arg(osName);
-  info << Q("* Version: %1").arg(osVersion.isEmpty() ? Q("unknown") : osVersion);
+  info << Q("* Version: %1").arg(osVersion);
   info << Q("* Pretty name: %1").arg(QSysInfo::prettyProductName());
 }
 
@@ -105,6 +114,19 @@ gatherScreenInfo(QStringList &info) {
 #endif
 }
 
+void
+gatherEnvironmentVariables(QStringList &info) {
+  info << Q("") << Q("## Environment variables") << Q("");
+
+  auto keys = QStringList{} << Q("QT_AUTO_SCREEN_SCALE_FACTOR") << Q("QT_SCALE_FACTOR") << Q("QT_SCREEN_SCALE_FACTORS") << Q("QT_DEVICE_PIXEL_RATIO")
+                            << Q("MTX_LOGGER")                  << Q("MTX_DEBUG")       << Q("MKVTOOLNIX_DEBUG")        << Q("MKVMERGE_DEBUG")
+                            << Q("LC_ALL")                      << Q("LC_MESSAGES")     << Q("LC_CTYPE")                << Q("LANG") << Q("LANGUAGE");
+  keys.sort();
+
+  for (auto const &name : keys)
+    info << Q("* `%1=%2`").arg(name).arg(Q(mtx::sys::get_environment_variable(to_utf8(name))));
+}
+
 void
 gatherQtInfo(QStringList &info) {
   info << Q("") << Q("# Qt") << Q("");
@@ -120,11 +142,6 @@ gatherQtInfo(QStringList &info) {
   info << Q("* Compiler: unknown");
 #endif
 
-  info << Q("") << Q("## Environment variables") << Q("");
-
-  auto keys = QStringList{} << Q("QT_AUTO_SCREEN_SCALE_FACTOR") << Q("QT_SCALE_FACTOR") << Q("QT_SCREEN_SCALE_FACTORS") << Q("QT_DEVICE_PIXEL_RATIO");
-  for (auto const &name : keys)
-    info << Q("* `%1=%2`").arg(name).arg(Q(mtx::sys::get_environment_variable(to_utf8(name))));
 }
 
 } // anonymous namespace
@@ -139,6 +156,8 @@ gatherSystemInformation() {
 
   gatherOperatingSystemInfo(info);
   gatherScreenInfo(info);
+  gatherEnvironmentVariables(info);
+
   gatherQtInfo(info);
 
   return info.join(Q("\n"));
